'+===================================================================================
'+               This file contains constants and function declarations
'+                      used in conjunction with ALLText HT/Pro
'+===================================================================================

' AllText limitations
Global Const ATX_MAXPARAG = 1000000          ' Max Number of paragraphs
Global Const ATX_MAXCHARS = 30000            ' Max Number of characters per paragraph
Global Const ATX_MINTEXTWIDTH = 40           ' Min Text Width  in pixels
Global Const ATX_MAXTEXTWIDTH = 32000        ' Max Text Width  in pixels
Global Const ATX_MAXTEXTHEIGHT = 2000000000  ' Max Text Height in pixels
Global Const ATX_MINTABSET = 16              ' Min Tabulation setting in pixels
Global Const ATX_MAXTABSET = 10000           ' Max Tabulation setting in twips
Global Const ATX_MAXFONTSIZE = 32000         ' Max Font Size in points
Global Const ATX_MAXSPACING = 32000          ' Max Font Size in points

' Error constants
Global Const ATX_NOMEM = 15001         ' NOT ENOUGH MEMORY
Global Const ATX_NOGDIMEM = 15002      ' NOT ENOUGH GDI MEMORY
Global Const ATX_BADGDIHANDLE = 15003  ' CAN'T CREATE DEVICE CONTEXT
Global Const ATX_TOOMANY_PARS = 15101  ' TOO MANY PARAGRAPHS PER TEXT
Global Const ATX_TOOMANY_CHARS = 15102 ' TOO MANY CHARACTERS PER PARAGRAPH
Global Const ATX_TOOMANY_LINES = 15103 ' TOO MANY LINES PER PARAGRAPH
Global Const ATX_TOOMANY_WORDS = 15104 ' TOO MANY WORDS PER PARAGRAPH
Global Const ATX_TOOMANY_FONTS = 15105 ' TOO MANY FONTS PER PARAGRAPH
'--------------------------------

' Common constants
Global Const ATX_UNDEFINED = -4096
Global Const ATX_PAR_UNDEFINED = -32000
Global Const ATX_DEFAULT = 0

' Protection constants
Global Const ATX_PROTECT_NONE = 0
Global Const ATX_PROTECT_CHANGES = -1
Global Const ATX_PROTECT_KEYBOARD = 1
Global Const ATX_PROTECT_SCREEN = 2

' Font family constants
Global Const ATX_DONTCARE = 0
Global Const ATX_ROMAN = 1
Global Const ATX_SWISS = 2
Global Const ATX_MODERN = 3
Global Const ATX_SCRIPT = 4
Global Const ATX_DECORATIVE = 5

' Font CharSet values
Global Const ATX_ANSI_CHARSET = 0
Global Const ATX_DEFAULT_CHARSET = 1
Global Const ATX_SYMBOL_CHARSET = 2
Global Const ATX_SHIFTJIS_CHARSET = 128
Global Const ATX_HANGEUL_CHARSET = 129
Global Const ATX_CHINESEBIG5_CHARSET = 136
Global Const ATX_OEM_CHARSET = 255

' Paragraph alignment constants
Global Const ATX_LEFT = 0
Global Const ATX_RIGHT = 1
Global Const ATX_CENTERED = 2
Global Const ATX_JUSTIFIED = 3

'color constants
Global Const ATX_Black = 0
Global Const ATX_Blue = 1
Global Const ATX_Green = 2
Global Const ATX_Cyan = 3
Global Const ATX_Red = 4
Global Const ATX_Magenta = 5
Global Const ATX_Yellow = 6
Global Const ATX_White = 7
Global Const ATX_Gray = 8
Global Const ATX_LT_Blue = 9
Global Const ATX_LT_Green = 10
Global Const ATX_LT_Cyan = 11
Global Const ATX_LT_Red = 12
Global Const ATX_LT_Magenta = 13
Global Const ATX_LT_Yellow = 14
Global Const ATX_LT_White = 15
Global Const ATX_Color_Undefined = 16

' Underline constants:
Global Const ATX_NONE = 0
Global Const ATX_SOLID = 1
Global Const ATX_DASH = 2
Global Const ATX_DOT = 3
Global Const ATX_DASHDOT = 4
Global Const ATX_DASHDOTDOT = 5
Global Const ATX_DOUBLE = 1
Global Const ATX_SINGLE = 0

' Background Style constants
Global Const ATX_Transparent = 0
Global Const ATX_Opaque = 1

' I/O format constants
Global Const ATX_FORMAT_TEXT = 0
Global Const ATX_FORMAT_S = 1
Global Const ATX_FORMAT_F = 2
Global Const ATX_FORMAT_RTF = 3     ' for HT edition only.
Global Const ATX_FORMAT_FLX = 4     ' for HT edition only.
Global Const ATX_FORMAT_USER = 4    ' for HT edition only.

' I/O mode constants
Global Const ATX_IO_COMPLETED = 0
Global Const ATX_IO_FAST = 1
Global Const ATX_IO_STANDARD = 2
Global Const ATX_IO_LOWLEVEL = 3

' SelFType and ExtDataType masks (for HT edition only).
Global Const ATX_FNTTBL_MASK = 1        'font table
Global Const ATX_CLRTBL_MASK = 2        'color table
Global Const ATX_PRGSET_MASK = 4        'paragraph settings
Global Const ATX_OLEOBJ_MASK = 8        'ole objects
Global Const ATX_RTFSTD_MASK = 16       '"rtf1...", "}", spec. sym. conversion,
Global Const ATXS_MASK = ATX_PRGSET_MASK
Global Const ATXF_MASK = ATXS_MASK Or ATX_FNTTBL_MASK Or ATX_OLEOBJ_MASK
Global Const FULLRTF_MASK = &H3F

' Tabulation constants
Global Const ATX_TAB_UNDEFINED = -32000
Global Const ATX_TAB_MIN_PIX = 16       ' for HT edition only.
Global Const ATX_TAB_LEFT = 0           ' for HT edition only.
Global Const ATX_TAB_CENTERED = 1       ' for HT edition only.
Global Const ATX_TAB_CENTRED = 1        ' for HT edition only.
Global Const ATX_TAB_RIGHT = 2          ' for HT edition only.

' Border constants                      ' for HT edition only.
Global Const ATX_BORDER_NONE = 0
Global Const ATX_BORDER_LEFT = 1
Global Const ATX_BORDER_RIGHT = 2
Global Const ATX_BORDER_TOP = 4
Global Const ATX_BORDER_BOTTOM = 8
Global Const ATX_BORDER_BOX = 15
Global Const ATX_BORDER_LINE_STANDARD = 0
Global Const ATX_BORDER_LINE_THICK = 1
Global Const ATX_BORDER_LINE_DOUBLE = 2
Global Const ATX_BORDER_NOTSHADOWED = 0
Global Const ATX_BORDER_SHADOWED = 1

'cut copy paste Clipboard action
Global Const ATX_CUT = 1
Global Const ATX_COPY = 2
Global Const ATX_PASTE = 3

' Hard Coded left indent of text from window margin in pixels
Global Const ATXLEFTSHIFT = 3


'======================================
'============PRINT SUPPORT ============
'======================================

' constants for Flags% parameters in print functions
Global Const ATX_PRINT_BACKPICTURE = 1 ' for new and old functions
Global Const ATX_PRINTOLD_NODIALOG = 2 ' only for old functions

Declare Function ATX_PRINT_START Lib "atx40h.vbx" (ByVal FormWnd%, ByVal hdc%, ByVal log_n%, ByVal rel_n%) As Integer
Declare Sub ATX_PRINT_FINISH Lib "atx40h.vbx" ()
Declare Sub ATX_PRINT_TITLE Lib "atx40h.vbx" (ByVal TitleString$)
Declare Function ATX_PRINT Lib "atx40h.vbx" (hctl As Control, StartTop&, ByVal Top_Indent&, ByVal TextOnPageY&, ByVal LeftIndent&, ByVal DocWidth&, ByVal ParFrom&, ByVal ParTo&, ByVal Flags%) As Integer
Declare Function ATX_PRINT_REGION Lib "atx40h.vbx" (hctl As Control, StartTop&, ByVal TextOnPageY&, ByVal LeftIndent&, ByVal DocWidth&, ByVal ParFrom&, ByVal ParTo&, ByVal Flags%) As Integer

'Printer error codes by above functions
Global Const ATX_PRINT_OK = 0
Global Const ATX_PRINT_ERR_NODEFPRINTER = 101
Global Const ATX_PRINT_ERR_NOSUPPORTPRINTER = 102
Global Const ATX_PRINT_ERR_INVALIDARGS = 103
Global Const ATX_PRINT_ERR_NOROOM = 104
Global Const ATX_PRINT_ERR_PRINTERROR = 105
Global Const ATX_PRINT_ERR_NOPRINTSTART = 106
Global Const ATX_PRINT_ERR_INVALIDSCALE = 107
Global Const ATX_PRINT_ERR_INVALPARAGRAPHRANGE = 108
Global Const ATX_PRINT_ERR_REGIONTOOSMALL = 109
Global Const ATX_PRINT_ERR_CANCEL = 110
Global Const ATX_PRINT_ERR_FATAL = 113

Declare Function Print_ATextPages Lib "atx40h.vbx" (alltext As Control, ByVal ptop&, ByVal pbottom&, ByVal pleft&, ByVal pwidth&, ByVal pages$, ByVal Flags%) As Integer
Declare Function Print_AText Lib "atx40h.vbx" (alltext As Control, ByVal ptop&, ByVal pbottom&, ByVal pleft&, ByVal pwidth&, ByVal start_par%, ByVal end_par%, ByVal Flags%) As Integer

'' Print_ATextPages and  Print_AText - status returned:
Global Const ERR_ATX_ABORT = 1
Global Const ERR_ATX_NOROOM = 29100 + 1
Global Const ERR_ATX_INVALIDARGS = 29100 + 2
Global Const ERR_ATX_NODEFPRINTER = 29100 + 3
Global Const ERR_ATX_PRINTERROR = 29100 + 4
Global Const ERR_ATX_NOSUPPORTPRINTER = 29100 + 5

'======================================
'========= ATXCHANGE SUPPORT ==========
'======================================
Global Const ATXTAG_CHANGED = 1
Global Const ATXMOUSE_CHANGED = 2
Global Const ATXFONT_CHANGED = 3
Global Const ATXCOLOR_CHANGED = 4
Global Const ATXCURSORLOCATION_CHANGED = 5
Global Const ATXSELECTION_CHANGED = 6
Global Const ATXLOCATIONX_CHANGED = 7
Global Const ATXLOCATIONY_CHANGED = 8
Global Const ATXSELPARAGS_CHANGED = 9
Global Const ATXPARALIGNMENT_CHANGED = 10
Global Const ATXMARGINX_CHANGED = 11
Global Const ATXSCROLLH_CHANGED = 12
Global Const ATXSCROLLV_CHANGED = 13
Global Const ATXPAGE_CHANGED = 14
Global Const ATXPAGELINE_CHANGED = 15
Global Const ATXLINE_CHANGED = 16
Global Const ATXFORMATED_CHANGED = 17
Global Const ATXCHANGED_CHANGED = 18

Global Const ATXTAG_CHANGED_MASK = &H1&
Global Const ATXMOUSE_CHANGED_MASK = &H2&
Global Const ATXFONT_CHANGED_MASK = &H4&
Global Const ATXCOLOR_CHANGED_MASK = &H8&
Global Const ATXCURSORLOCATION_CHANGED_MASK = &H10&
Global Const ATXSELECTION_CHANGED_MASK = &H20&
Global Const ATXLOCATIONX_CHANGED_MASK = &H40&
Global Const ATXLOCATIONY_CHANGED_MASK = &H80&
Global Const ATXSELPARAGS_CHANGED_MASK = &H100&
Global Const ATXPARALIGNMENT_CHANGED_MASK = &H200&
Global Const ATXMARGINX_CHANGED_MASK = &H400&
Global Const ATXSCROLLH_CHANGED_MASK = &H800&
Global Const ATXSCROLLV_CHANGED_MASK = &H1000&
Global Const ATXPAGE_CHANGED_MASK = &H2000&
Global Const ATXPAGELINE_CHANGED_MASK = &H4000&
Global Const ATXLINE_CHANGED_MASK = &H8000&
Global Const ATXFORMATED_CHANGED_MASK = &H10000
Global Const ATXCHANGED_CHANGED_MASK = &H20000

Global Const ATXCHANGED_USER_MASK = &H80000000


'======================================
'=========   UNDO SUPPORT    ==========
'======================================

Global Const ATX_UNDO_RESET = 0
Global Const ATX_UNDO_STEP = 1

'======================================
'======= Header/Footer Support ========
'======================================

Global Const ATX_HEADER_SIMPLE = 0
Global Const ATX_HEADER_LEFT = 1
Global Const ATX_HEADER_RIGHT = 2
Global Const ATX_HEADER_FIRST = 3

Global Const ATX_FOOTER_SIMPLE = 0
Global Const ATX_FOOTER_LEFT = 1
Global Const ATX_FOOTER_RIGHT = 2
Global Const ATX_FOOTER_FIRST = 3

'======================================
'====== HYPERTEXT AND BOOKMARKS =======
'======================================

Declare Function Find_HTag Lib "atx40h.vbx" (alltext As Control, ByVal htag&, ByVal skipcount&) As Long
Declare Function Find_NTag Lib "atx40h.vbx" (alltext As Control, ByVal htag&, ByVal skipcount&) As Long
Declare Function FIND_PTAG Lib "atx40h.vbx" (alltext As Control, ByVal ptag&, ByVal skipcount&) As Long
Global Const ATX_MAXNEWHTAG = 64000                 ' Max Htag Number can be returned by NewHtag property
Global Const ATX_MAXMOUSEHPOINTER = 14
Global Const ATX_TAG_UNDEFINED = -2147483648#


'======================================
'====== Coordinate Translation  =======
'======================================
Declare Function ATX_CurToXY Lib "atx40h.vbx" (alltext As Control, ByVal p&, ByVal c%, x1&, y1&) As Integer
Declare Function ATX_XYToCur Lib "atx40h.vbx" (alltext As Control, ByVal x&, ByVal y&, p&, c%) As Integer

'======================================
'====== FONT TABLE SUPPORT  =======
'======================================
Declare Function FontTablePut Lib "atx40h.vbx" (alltext As Control, ByVal Num%, ByVal fam%, ByVal CharSet%, fntname$, ByVal H%, ByVal FntWidth%, ByVal Bold%, ByVal Italic%, ByVal Underline%, ByVal StrikeOut%, ByVal shadow%, ByVal SubSup%) As Integer
Declare Function FontTableGet Lib "atx40h.vbx" (alltext As Control, ByVal Num%, fam%, CharSet%, fntname$, H%, FntWidth%, Bold%, Italic%, Underline%, StrikeOut%, shadow%, SubSup%) As Integer

'======================================
'= COLOR, BORDER, SHADOW & UNDERLINE ==
'======================================
Declare Function make_shadow Lib "atx40h.vbx" (ByVal delt1%, ByVal delt2%, ByVal color1%, ByVal color2%) As Integer
Declare Sub get_shadow Lib "atx40h.vbx" (ByVal shadow%, delt1%, delt2%, color1%, color2%)
Declare Function color_index Lib "atx40h.vbx" (ByVal rgb_color&) As Integer
Declare Function make_underline Lib "atx40h.vbx" (ByVal shape%, ByVal dblflag%, ByVal ncolor%) As Integer
Declare Sub get_underline Lib "atx40h.vbx" (ByVal underval%, shape%, dblflag%, ncolor%)
Declare Function make_border Lib "atx40h.vbx" (ByVal side%, ByVal shape%, ByVal shadow%) As Long
Declare Sub get_border Lib "atx40h.vbx" (ByVal border&, side%, shape%, shadow%)

Declare Sub GET_PARDET Lib "atx40h.vbx" (alltext As Control, ByVal paragraph&, top&, height&, FirstLineIndent&, LineSpace&, SpaceAfter&, SpaceBefore&)
Declare Sub get_linetopheight Lib "atx40h.vbx" (alltext As Control, ByVal paragraph&, ByVal linenum&, top&, height&)
Declare Function find_phrase Lib "atx40h.vbx" (alltext As Control, ByVal What As String, ByVal Direction%, ByVal CaseSensitive%) As Long
Declare Function find_phraseEX Lib "atx40h.vbx" (alltext As Control, ByVal What As String, ByVal Direction%, ByVal CaseSensitive%, ByVal SearchFontName As String, ByVal SearchFontHt%, ByVal SearchFontWd%, ByVal SearchFontBl%, ByVal SearchFontIt%, ByVal SearchFontUl%, ByVal SearchFontSt%, ByVal SearchFontSh%, ByVal SearchFontSu%, ByVal SearchFontCol&, ByVal SearchFontHi%, ByVal SearchFontTag&, FoundPos&, FoundLen&) As Long

'======================================
'========= Case Translation  ==========
'======================================

Declare Sub ATX_TOUPPER Lib "atx40h.vbx" (hctl As Control)
Declare Sub ATX_TOLOWER Lib "atx40h.vbx" (hctl As Control)

'======================================
'==Register Pictures and OLE Objects==
'======================================
Declare Function ATX_REGNEWEXTERN Lib "atx40h.vbx" (ByVal noMsg%, ByVal lpstrModule$) As Integer

'======================================
'================ OLE  ================
'======================================
Declare Function GET_OLESERV Lib "atx40h.vbx" (ByVal ne As Integer) As String
Global Const ATX_VERB_UNDEFINED = -32000

' ====================================
' Functions now under test.  Documentation to follow at a later date
' ====================================
' Used by Roolfrm and ToolFrm
Declare Function GET_FONTSIZE Lib "atx40h.vbx" (ByVal fontNom%, ByVal fntname$) As Integer
Declare Function GET_FONTNAME Lib "atx40h.vbx" (ByVal fontNom%) As String

